@@ -205,7 +205,6 @@ def _get_cert_policy_language(x509):
     """
     ext = x509.extensions.get_extension_for_oid(PROXY_CERT_INFO_EXT_OID)
     for line in ext.value.value.split():
-        print(line)
         if line.endswith(b"+\x06\x01\x05\x05\x07\x15\x01"):
             return "Inherit all"
         if line.endswith(b"+\x06\x01\x04\x01\x9bP\x01\x01\x01"):
@@ -293,28 +292,24 @@ def write_cert(path, cert, key, use_proxy=False, minhours=168):
         `proxy=True` is given
     """
     if use_proxy:
-        # generate proxy
-        proxy, proxykey = generate_proxy(cert, key, minhours=minhours)
-        # write the proxy cert, key pair _and_ the original cert
-        blocks = [
-            proxy.public_bytes(encoding=Encoding.PEM),
-            proxykey.private_bytes(
-                encoding=Encoding.PEM,
-                format=PrivateFormat.PKCS8,
-                encryption_algorithm=NoEncryption(),
-            ),
-            cert.public_bytes(encoding=Encoding.PEM),
-        ]
+        # we will store the original certificate as part of the signing chain
+        chain = [cert.public_bytes(encoding=Encoding.PEM)]
+        # generate a self-signed proxy
+        cert, key = generate_proxy(cert, key, minhours=minhours)
     else:
-        # write the cert, key pair
-        blocks = [
-            cert.public_bytes(encoding=Encoding.PEM),
-            key.private_bytes(
-                encoding=Encoding.PEM,
-                format=PrivateFormat.PKCS8,
-                encryption_algorithm=NoEncryption(),
-            ),
-        ]
+        chain = []
+
+    # write the cert, key pair, and the signing chain (if any)
+    blocks = [
+        # the cert
+        cert.public_bytes(encoding=Encoding.PEM),
+        # the private key associated with the cert's public key
+        key.private_bytes(
+            encoding=Encoding.PEM,
+            format=PrivateFormat.PKCS8,
+            encryption_algorithm=NoEncryption(),
+        ),
+    ] + chain
 
     with tempfile.NamedTemporaryFile(delete=False) as tmp:
         # write cert and key to temporary location
@@ -377,14 +372,14 @@ def generate_proxy(cert, key, minhours=168, limited=False, bits=2048):
 
     # generate a new subject by appending the serial number to
     # the subject of the original certificate
-    proxy_subject = crypto_x509.Name(cert.subject.rdns + [
-        crypto_x509.RelativeDistinguishedName([
+    proxy_subject = crypto_x509.Name(
+        list(cert.subject) + [
             crypto_x509.NameAttribute(
                 crypto_x509.NameOID.COMMON_NAME,
                 str(serial),
             ),
-        ]),
-    ])
+        ]
+    )
 
     # add extensions
     extensions = [crypto_x509.Extension(
@@ -429,7 +424,7 @@ def generate_proxy(cert, key, minhours=168, limited=False, bits=2048):
         extensions=extensions,
     ).add_extension(proxyinfoext, critical=True)
     proxy = builder.sign(
-        private_key=proxy_private_key,
+        private_key=key,
         algorithm=hashes.SHA256(),
         backend=default_backend(),
     )
